editscript.util.index


indexclj/s

(index data)
(index data context)

Build a lazy indexing tree. Subtree metadata is computed up front, while child Nodes and sibling links are created only when their parent is explored. A context may be shared when indexing structurally shared inputs.

Build a lazy indexing tree. Subtree metadata is computed up front, while
child Nodes and sibling links are created only when their parent is explored.
A context may be shared when indexing structurally shared inputs.
sourceraw docstring

index-contextclj/s

(index-context)

Create metadata storage that can be shared by indexes over shared data.

Create metadata storage that can be shared by indexes over shared data.
sourceraw docstring

INodeclj/sprotocol

get-keyclj/s

(get-key this)

Get the key of this node

Get the key of this node

children-realized?clj/s

(children-realized? this)

Whether this node has realized its children

Whether this node has realized its children

realize-childrenclj/s

(realize-children this)

Realize this node's immediate children

Realize this node's immediate children

get-sizeclj/s

(get-size this)

Get the size of sub-tree, used to estimate cost

Get the size of sub-tree, used to estimate cost

set-nextclj/s

(set-next this node)

Set the next sibling node

Set the next sibling node

get-parentclj/s

(get-parent this)

Get the parent node

Get the parent node

get-firstclj/s

(get-first this)

Get the first child node

Get the first child node

get-lastclj/s

(get-last this)

Get the last child node

Get the last child node

get-pathclj/s

(get-path this)

Get the path to the node from root

Get the path to the node from root

get-valueclj/s

(get-value this)

Get the actual data

Get the actual data

get-nextclj/s

(get-next this)

Get the next sibling node

Get the next sibling node

get-childrenclj/s

(get-children this)

Get child nodes in their keyed lookup collection

Get child nodes in their keyed lookup collection

get-orderclj/s

(get-order this)

Get the order of this node in traversal

Get the order of this node in traversal
source

cljdoc builds & hosts documentation for Clojure/Script libraries