(index data)(index data context)Build a lazy indexing tree. Subtree metadata is computed up front, while child Nodes and sibling links are created only when their parent is explored. A context may be shared when indexing structurally shared inputs.
Build a lazy indexing tree. Subtree metadata is computed up front, while child Nodes and sibling links are created only when their parent is explored. A context may be shared when indexing structurally shared inputs.
(index-context)Create metadata storage that can be shared by indexes over shared data.
Create metadata storage that can be shared by indexes over shared data.
(get-key this)Get the key of this node
Get the key of this node
(children-realized? this)Whether this node has realized its children
Whether this node has realized its children
(realize-children this)Realize this node's immediate children
Realize this node's immediate children
(get-size this)Get the size of sub-tree, used to estimate cost
Get the size of sub-tree, used to estimate cost
(set-next this node)Set the next sibling node
Set the next sibling node
(get-parent this)Get the parent node
Get the parent node
(get-first this)Get the first child node
Get the first child node
(get-last this)Get the last child node
Get the last child node
(get-path this)Get the path to the node from root
Get the path to the node from root
(get-value this)Get the actual data
Get the actual data
(get-next this)Get the next sibling node
Get the next sibling node
(get-children this)Get child nodes in their keyed lookup collection
Get child nodes in their keyed lookup collection
(get-order this)Get the order of this node in traversal
Get the order of this node in traversal
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |